@@ -53,10 +53,11 @@ if [[ $(diff -U 0 --suppress-common-lines -b Dockerfile.2 Dockerfile) ]] || [[ $
   curl -sSL http://mirror.csclub.uwaterloo.ca/apache/maven/maven-3/${MAVEN_VERSION}/binaries/apache-maven-${MAVEN_VERSION}-bin.tar.gz | \
     tar -xz --strip=1 -C apache-maven/
     
-  tar czf bin.tgz gradle/ apache-maven/
-	log "[INFO] Upload new sources: bin.tgz"
-  rhpkg new-sources bin.tgz
-	log "[INFO] Commit new sources"
+  tar czf gradle.tgz gradle/
+  tar czf maven.tgz apache-maven/
+  log "[INFO] Upload new sources: gradle.tgz maven.tgz"
+  rhpkg new-sources gradle.tgz maven.tgz
+  log "[INFO] Commit new sources"
   # COMMIT_MSG="graalvm CE JDK11 + native-image ${GRAALVM_VERSION}, "
   COMMIT_MSG="${COMMIT_MSG}Gradle ${GRADLE_VERSION}, Maven ${MAVEN_VERSION}"
 	if [[ $(git commit -s -m "[get sources] ${COMMIT_MSG}" sources Dockerfile) == *"nothing to commit, working tree clean"* ]]; then 
